# Coastal Hazards Toolkit - Meteo

A package to download meteorological forecasts and hindcasts from different sources.

Right now, GFS hindcasts and forecasts are available.

Coamps-TC forecast data is also available.

The package is designed to be easily extensible to other sources.
